@@ -13,8 +13,14 @@
 
 #include <stdio.h>
 
+#include "mkc_externc.h"
+
+__MKC_BEGIN_DECLS
+
 #ifndef HAVE_FUNC2_FGETLN_STDIO_H
 char *fgetln (FILE *stream, size_t *len);
 #endif
 
+__MKC_END_DECLS
+
 #endif // _MKC_FGETLN_H_
